@@ -5,37 +5,37 @@
 #'
 #' Creates an interactive graph of phenotypes vs genotypes at a marker.
 #'
-#' @param cross Object of class \code{"cross"}, see
-#'   \code{\link[qtl]{read.cross}}.
+#' @param cross Object of class `"cross"`, see
+#'   [qtl::read.cross()].
 #' @param marker Character string with marker name.
 #' @param pheno.col Phenotype column in cross object.
 #' @param chartOpts A list of options for configuring the chart.  Each
 #'   element must be named using the corresponding option.
 #' @param fillgenoArgs List of named arguments to pass to
-#'   \code{\link[qtl]{fill.geno}}, if needed.
+#'   [qtl::fill.geno()], if needed.
 #' @param digits Round data to this number of significant digits
 #'     before passing to the chart function. (Use NULL to not round.)
 #'
-#' @return An object of class \code{htmlwidget} that will
+#' @return An object of class `htmlwidget` that will
 #' intelligently print itself into HTML in a variety of contexts
 #' including the R console, within R Markdown documents, and within
 #' Shiny output bindings.
 #'
-#' @details The function \code{\link[qtl]{fill.geno}} is used to
+#' @details The function [qtl::fill.geno()] is used to
 #' impute missing genotypes, with arguments passed as a list, for
-#' example \code{fillgenoArgs=list(method="argmax", error.prob=0.002,
-#' map.function="c-f")}.
+#' example `fillgenoArgs=list(method="argmax", error.prob=0.002,
+#' map.function="c-f")`.
 #'
 #' Individual IDs (viewable when hovering over a point) are taken from
-#' the input \code{cross} object, using the \code{\link[qtl]{getid}}
+#' the input `cross` object, using the [qtl::getid()]
 #' function in R/qtl.
 #'
 #' By default, points are colored blue and pink according to whether
 #' the marker genotype is observed or inferred, respectively.
 #'
 #' @keywords hplot
-#' @seealso \code{\link{idotplot}}, \code{\link{iplot}}, \code{\link{iplotScanone}},
-#' \code{\link{iplotMap}}
+#' @seealso [idotplot()], [iplot()], [iplotScanone()],
+#' [iplotMap()]
 #'
 #' @examples
 #' library(qtl)
@@ -52,7 +52,7 @@ iplotPXG <-
 function(cross, marker, pheno.col=1,
          chartOpts=NULL, fillgenoArgs=NULL, digits=5)
 {
-    if(class(cross)[2] != "cross")
+    if(!inherits(cross, "cross"))
         stop('"cross" should have class "cross".')
 
     if(length(marker) > 1) {
